/* Common user parameters for Code Saturne */
/* Based on Code Saturne examples */
/* Original name: cs_user_parameters.c */

/* Headers */
#include "cs_defs.h"

/* Standard C headers */
#include <assert.h>
#include <math.h>
#include <string.h>

/* MPI headers */
#if defined(HAVE_MPI)
#include <mpi.h>
#endif

/* PLE library headers */
#include <ple_coupling.h>

/* Local headers */
#include "cs_headers.h"

BEGIN_C_DECLS

/* Set user parameters */
void cs_user_parameters(cs_domain_t *domain)
{
 int idTurbFluxRc;
 double prsRlxCoef,velRlxCoef,turbRlxCoef,entRlxCoef;
 cs_field_t* field;
 cs_equation_param_t* eqnPar;
 /* Parameters */
 /* Relexation factors */
 prsRlxCoef=0.1; /* Pressure relaxation */
 velRlxCoef=0.1; /* Velocity relaxation */
 turbRlxCoef=0.8; /* Turbulence relaxation */
 entRlxCoef=0.5; /* Enthalpy relaxation */
 /* Flux reconstruction flags */
 idTurbFluxRc=0; /* Turbulence flux reconstruction */
 /* Velocity field options */
 field=CS_F_(vel); /* Field structure */
 if (field!=NULL) /* Field present */
 {
  eqnPar=cs_field_get_equation_param(field); /* Field options structure */
  eqnPar->relaxv=velRlxCoef; /* Relaxation factor */
 };
 /* Pressure field options */
 field=CS_F_(p); /* Field structure */
 if (field!=NULL) /* Field present */
 {
  eqnPar=cs_field_get_equation_param(field); /* Field options structure */
  eqnPar->relaxv=prsRlxCoef; /* Relaxation factor */
 };
 /* Turbulence: k for k-epsilon */
 field=CS_F_(k); /* Field structure */
 if (field!=NULL) /* Field present */
 {
  eqnPar=cs_field_get_equation_param(field); /* Field options structure */
  eqnPar->relaxv=turbRlxCoef; /* Relaxation factor */
  eqnPar->ircflu=idTurbFluxRc; /* Flux reconstruction flag */
 };
 /* Turbulence: epsilon for k-epsilon and RSM */
 field=CS_F_(eps); /* Field structure */
 if (field!=NULL) /* Field present */
 {
  eqnPar=cs_field_get_equation_param(field); /* Field options structure */
  eqnPar->relaxv=turbRlxCoef; /* Relaxation factor */
  eqnPar->ircflu=idTurbFluxRc; /* Flux reconstruction flag */
 };
 /* Turbulence: Rij for RSM */
 field=CS_F_(rij); /* Field structure */
 if (field!=NULL) /* Field present */
 {
  eqnPar=cs_field_get_equation_param(field); /* Field options structure */
  eqnPar->relaxv=turbRlxCoef; /* Relaxation factor */
  eqnPar->ircflu=idTurbFluxRc; /* Flux reconstruction flag */
 };
 /* Enthalpy field options */
 field=CS_F_(h); /* Field structure */
 if (field!=NULL) /* Field present */
 {
  eqnPar=cs_field_get_equation_param(field); /* Field options structure */
  eqnPar->relaxv=entRlxCoef; /* Relaxation factor */
 };
}

END_C_DECLS
